@@ -126,7 +126,7 @@ def _run_command(entry, replace, background, argstr):
     doc = entry.view().get_buffer()
 
     if not doc.is_untitled() and doc.is_local():
-        gfile = doc.get_location()
+        gfile = doc.get_file().get_location()
         cwd = os.path.dirname(gfile.get_path())
 
     if '<!' in argstr:
@@ -139,7 +139,7 @@ def _run_command(entry, replace, background, argstr):
 
         # Write to temporary file
         tmpin = tempfile.NamedTemporaryFile(delete=False)
-        tmpin.write(inp)
+        tmpin.write(inp.encode('utf-8'))
         tmpin.flush()
 
         # Replace with temporary file
